==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/template/barnraiser_01/sn_network.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="100%" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="370" valign="top">
			<div class="box_top">
				<?php echo $lang['section_statistics'];?><br />
			</div>

			<div class="box_mid" style="padding: 9px;">
			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<tr>
					<td valign="top">
						<b><?php echo $lang['txt_social_network'];?></b><br />
						<?php echo $lang['txt_social_network_intro'];?>
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" border="0" cellspacing="2" cellpadding="2" class="picture_light">
				<?php
				$total = 0;
				if (isset($network)) {

				foreach($network as $key => $i):
				?>
				<tr>
					<td class="bg3">
						<?php echo $lang['sn']['degree'][$i['degree_id']];?><br />
						<span class="txt_footer">
						<?php echo $lang['sn']['degree_desc'][$i['degree_id']];?><br />
						</span>
					</td>
					<td align="center" valign="top" class="bg4" width="10%">
						<?php
						$sub_total = 0;
						if (isset($i['sn_total']) && $i['sn_total'] > 0) {
						    $sub_total = $i['sn_total'];
						}

						echo $sub_total;
						$total = $total+$sub_total;
						?>
					</td>
				</tr>

				<?php
				endforeach;
				}?>
				<tr>
					<td class="bg3">
						<?php echo $lang['txt_outstanding_invites'];?><br />
						<span class="txt_footer">
						<?php echo $lang['txt_outstanding_invites_intro'];?><br />
						</span>
					</td>
					<td align="center" valign="top" class="bg4">
						<?php
						$sub_total = 0;
						if (isset($outstanding_invites) && $outstanding_invites > 0) {
						    $sub_total = $outstanding_invites;
						}

						echo $sub_total;
						$total = $total+$sub_total;
						?>
					</td>
				</tr>
				<tr>
					<td class="bg3">
						<?php echo $lang['txt_your_social_network'];?><br />
						<span class="txt_footer">
						<?php echo $lang['txt_your_social_network_intro'];?><br />
						</span>
					</td>
					<td align="center" valign="top" class="bg1">
						<?php echo $total;?>
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />

			<table width="100%" border="0" cellspacing="2" cellpadding="2" class="picture_light">
				<tr>
					<td class="bg3">
						<?php echo $lang['txt_total_online_users'];?>:<br />
					</td>
					<td align="center" valign="top" class="bg4" width="10%">
						<?php echo $alluser_statistics['total_online_users'];?><br />
					</td>
				</tr>
				<tr>
					<td class="bg3">
						<?php echo $lang['txt_total_users'];?>:<br />
					</td>
					<td align="center" valign="top" class="bg4">
						<?php echo $alluser_statistics['total_users'];?><br />
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2">
						<b><?php echo $lang['hdr_im_pending'];?></b><br />
					</td>
				</tr>
				<?php
				if (isset($pending)) {
				foreach($pending as $key => $i):
				?>
				<tr>
					<td>
						<?php echo $i['datetime'];?><br />
					</td>
					<td>
						<?php echo $i['email'];?><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_pending_requests'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
			</div>

			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>

		</td>

		<td width="20">&nbsp;</td>

		<td width="370" valign="top">
			<div class="box_top">
				<?php echo $lang['section_social_network'];?><br />
			</div>

			<div class="box_mid" style="padding: 9px;">
			<table width="100%" border="0" cellspacing="0" cellpadding="4" class="table_stnd">
				<tr>
					<td colspan="4">
						<b><?php echo $lang['section_social_network1'];?></b><br />

					</td>
				</tr>
				<?php
				if (isset($friends)) {
				foreach($friends as $key => $i):
				?>
				<tr>
					<td valign="middle" width="32">
						<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" alt="<?php echo $i['image']['file_title'];?>" /></a><br />
					</td>
					<td valign="middle" align="center" width="46">
						<?php echo $i['sn_total'];?><br />
					</td>
					<td valign="middle">
						<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><b><?php echo $i['profile_nic'];?></b></a>,

						<?php echo $i['profile_create_datetime'];?>,
						<?php echo $i['profile_hometown'];?>,

						<?php
						if ($i['online_status'] == 1) {
						    echo "<span class='txt_breadcrumb_on'><b>" . $lang['arr_user_online_status'][1] . "</b></span><br />";
						}
						else {
							    echo $lang['arr_user_online_status'][$i['online_status']] . "<br />";
						}
						?>
					</td>
					<td align="right">
						<?php
						if (isset($i['profile_allow_msg']) && $i['profile_allow_msg'] == 1) {
						?>
						<a href="msg_compose.php?to_user_id=<?php echo $i['user_id'];?>"><img src="<?php echo $templatePath;?>img/unopenned_mail.png" title="<?php echo $lang['ttl_send_message'];?>" border="0" alt="" /></a>&nbsp;&nbsp;<br />
						<?php }?>
					</td>
				</tr>
				<tr>
					<td colspan="4">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td colspan="4">
						<?php echo $lang['err_no_friends'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
			</div>

			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>

==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/template/barnraiser_01/sn_network.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="100%" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="370" valign="top">
			<div class="box_top">
				<?php echo $lang['section_statistics'];?><br />
			</div>

			<div class="box_mid" style="padding: 9px;">
			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<tr>
					<td valign="top">
						<b><?php echo $lang['txt_social_network'];?></b><br />
						<?php echo $lang['txt_social_network_intro'];?>
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" border="0" cellspacing="2" cellpadding="2" class="picture_light">
				<?php
				$total = 0;
				if (isset($network)) {

				foreach($network as $key => $i):
				?>
				<tr>
					<td class="bg3">
						<?php echo $lang['sn']['degree'][$i['degree_id']];?><br />
						<span class="txt_footer">
						<?php echo $lang['sn']['degree_desc'][$i['degree_id']];?><br />
						</span>
					</td>
					<td align="center" valign="top" class="bg4" width="10%">
						<?php
						$sub_total = 0;
						if (isset($i['sn_total']) && $i['sn_total'] > 0) {
						    $sub_total = $i['sn_total'];
						}

						echo $sub_total;
						$total = $total+$sub_total;
						?>
					</td>
				</tr>

				<?php
				endforeach;
				}?>
				<tr>
					<td class="bg3">
						<?php echo $lang['txt_outstanding_invites'];?><br />
						<span class="txt_footer">
						<?php echo $lang['txt_outstanding_invites_intro'];?><br />
						</span>
					</td>
					<td align="center" valign="top" class="bg4">
						<?php
						$sub_total = 0;
						if (isset($outstanding_invites) && $outstanding_invites > 0) {
						    $sub_total = $outstanding_invites;
						}

						echo $sub_total;
						$total = $total+$sub_total;
						?>
					</td>
				</tr>
				<tr>
					<td class="bg3">
						<?php echo $lang['txt_your_social_network'];?><br />
						<span class="txt_footer">
						<?php echo $lang['txt_your_social_network_intro'];?><br />
						</span>
					</td>
					<td align="center" valign="top" class="bg1">
						<?php echo $total;?>
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />

			<table width="100%" border="0" cellspacing="2" cellpadding="2" class="picture_light">
				<tr>
					<td class="bg3">
						<?php echo $lang['txt_total_online_users'];?>:<br />
					</td>
					<td align="center" valign="top" class="bg4" width="10%">
						<?php echo $alluser_statistics['total_online_users'];?><br />
					</td>
				</tr>
				<tr>
					<td class="bg3">
						<?php echo $lang['txt_total_users'];?>:<br />
					</td>
					<td align="center" valign="top" class="bg4">
						<?php echo $alluser_statistics['total_users'];?><br />
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2">
						<b><?php echo $lang['hdr_im_pending'];?></b><br />
					</td>
				</tr>
				<?php
				if (isset($pending)) {
				foreach($pending as $key => $i):
				?>
				<tr>
					<td>
						<?php echo $i['datetime'];?><br />
					</td>
					<td>
						<?php echo $i['email'];?><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_pending_requests'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td>
						<b><?php echo $lang['hdr_tag'];?></b><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php
						$tags = "";
						if (isset($my_tags)) {
							foreach ($my_tags as $key => $i):
								$tags .= "<a href='sn_network.php?tag=" . $i['tag_body']. "'>" . $i['tag_body'] . "</a>, ";
							endforeach;
							
							$tags .= "<a href='sn_network.php'>" . $lang['txt_view_all_network'] . "</a>";
						}
						echo $tags;
						?>
					</td>
				</tr>
			</table>
			</div>

			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>

		</td>

		<td width="20">&nbsp;</td>

		<td width="370" valign="top">
			<div class="box_top">
				<?php echo $lang['section_social_network'];?><br />
			</div>

			<div class="box_mid" style="padding: 9px;">
			<table width="100%" border="0" cellspacing="0" cellpadding="4" class="table_stnd">
				<tr>
					<td colspan="4">
						<b><?php echo $lang['section_social_network1'];?></b><br />

					</td>
				</tr>
				<?php
				if (isset($friends)) {
				foreach($friends as $key => $i):
				?>
				<tr>
					<td valign="middle" width="32">
						<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" alt="<?php echo $i['image']['file_title'];?>" /></a><br />
					</td>
					<td valign="middle" align="center" width="46">
						<?php echo $i['sn_total'];?><br />
					</td>
					<td valign="middle">
						<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><b><?php echo $i['profile_nic'];?></b></a>,

						<?php echo $i['profile_create_datetime'];?>,
						<?php echo $i['profile_hometown'];?>,

						<?php
						if ($i['online_status'] == 1) {
						    echo "<span class='txt_breadcrumb_on'><b>" . $lang['arr_user_online_status'][1] . "</b></span><br />";
						}
						else {
							    echo $lang['arr_user_online_status'][$i['online_status']] . "<br />";
						}
						?>
						<p>
							<?php echo $lang['txt_tag'];?>: 
	
							<?php
							$tags = "";
							if (isset($i['tags'])) {
								foreach ($i['tags'] as $keyt => $t):
									$tags .= $t['tag_body'];
									
									if (count($i['tags']) > $keyt+1) {
										$tags .= ", ";
									}
								endforeach;
								echo $tags;
							}
							?>
						</p>
					</td>
					<td align="right">
						<?php
						if (isset($i['profile_allow_msg']) && $i['profile_allow_msg'] == 1) {
						?>
						<a href="msg_compose.php?to_user_id=<?php echo $i['user_id'];?>"><img src="<?php echo $templatePath;?>img/unopenned_mail.png" title="<?php echo $lang['ttl_send_message'];?>" border="0" alt="" /></a>&nbsp;&nbsp;<br />
						<?php }?>
					</td>
				</tr>
				<tr>
					<td colspan="4">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td colspan="4">
						<?php echo $lang['err_no_friends'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
			</div>

			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>
